aboutsummaryrefslogtreecommitdiffstats
path: root/widgets/misc/e-search-bar.h
diff options
context:
space:
mode:
authorJon Trowbridge <trow@ximian.com>2001-08-16 14:17:18 +0800
committerJon Trowbridge <trow@src.gnome.org>2001-08-16 14:17:18 +0800
commitfef28ce070e3d25b8837ca8015936cb6b7ddf08d (patch)
treec4eecca87f2307c89bda29b838a4d7ecdc015945 /widgets/misc/e-search-bar.h
parentabbdee83ee54fab89c5d6d1dfd61e969be85c16b (diff)
downloadgsoc2013-evolution-fef28ce070e3d25b8837ca8015936cb6b7ddf08d.tar
gsoc2013-evolution-fef28ce070e3d25b8837ca8015936cb6b7ddf08d.tar.gz
gsoc2013-evolution-fef28ce070e3d25b8837ca8015936cb6b7ddf08d.tar.bz2
gsoc2013-evolution-fef28ce070e3d25b8837ca8015936cb6b7ddf08d.tar.lz
gsoc2013-evolution-fef28ce070e3d25b8837ca8015936cb6b7ddf08d.tar.xz
gsoc2013-evolution-fef28ce070e3d25b8837ca8015936cb6b7ddf08d.tar.zst
gsoc2013-evolution-fef28ce070e3d25b8837ca8015936cb6b7ddf08d.zip
Boost scoring on an exact nickname match. Manually addressify match.
2001-08-16 Jon Trowbridge <trow@ximian.com> * gui/component/select-names/e-select-names-completion.c (match_nickname): Boost scoring on an exact nickname match. Manually addressify match. (match_name): Manually addressify matches. (book_query_score): Remove automatic addressification. * gui/component/addressbook.c (addressbook_query_changed): Minor tweak to avoid a crash if we have a negative subid with id ESB_CATEGORY. This should never happen. (addressbook_menu_activated): Reset the entry/option when we select "Clear". Some changes to reflect renaming in ESearchBar. * gui/component/select-names/e-select-names-bonobo.c (entry_set_property_fn): Cardify after importing destinations. This might fix a problem that Damon is having. 2001-08-16 Jon Trowbridge <trow@ximian.com> * e-filter-bar.c (option_changed): Adjusted for renamed ESearchBar functions. (menubar_activated): Adjusted for renamed ESearchBar functions. * e-search-bar.c: Renames some of the horrible function names: s/option_choice/item_id/, s/suboption_choice/subitem_id/. 2001-08-16 Jon Trowbridge <trow@ximian.com> * gui/cal-search-bar.c: Changed to reflect my renaming of some of the more hideously-named functions in the ESearchBar API. svn path=/trunk/; revision=12081
Diffstat (limited to 'widgets/misc/e-search-bar.h')
-rw-r--r--widgets/misc/e-search-bar.h16
1 files changed, 9 insertions, 7 deletions
diff --git a/widgets/misc/e-search-bar.h b/widgets/misc/e-search-bar.h
index 0694682e02..3842fa8409 100644
--- a/widgets/misc/e-search-bar.h
+++ b/widgets/misc/e-search-bar.h
@@ -34,7 +34,8 @@ extern "C" {
*
* name type read/write description
* ---------------------------------------------------------------------------------
* option_choice int RW Which option choice is currently selected.
* text string RW Text in the entry box.
*/
@@ -79,8 +80,9 @@ struct _ESearchBar
GtkWidget *entry_box;
guint pending_change;
- int option_choice;
- int suboption_choice; /* < 0 if the entry widget is active */
+ /* The currently-selected item & subitem */
+ int item_id;
+ int subitem_id; /* < 0 if the entry widget is active */
};
struct _ESearchBarClass
@@ -111,11 +113,11 @@ GtkWidget *e_search_bar_new (ESearchBarItem *menu_items,
void e_search_bar_set_menu_sensitive(ESearchBar *search_bar, int id, gboolean state);
-void e_search_bar_set_option_choice (ESearchBar *search_bar, int id);
-int e_search_bar_get_option_choice (ESearchBar *search_bar);
+void e_search_bar_set_item_id (ESearchBar *search_bar, int id);
+int e_search_bar_get_item_id (ESearchBar *search_bar);
-void e_search_bar_set_suboption_choice (ESearchBar *search_bar, int id);
-int e_search_bar_get_suboption_choice (ESearchBar *search_bar);
+void e_search_bar_set_subitem_id (ESearchBar *search_bar, int id);
+int e_search_bar_get_subitem_id (ESearchBar *search_bar);
void e_search_bar_set_text (ESearchBar *search_bar, const char *text);
char *e_search_bar_get_text (ESearchBar *search_bar);
@@ -34,7 +34,8 @@ extern "C" {
* name type read/write description
* ---------------------------------------------------------------------------------
- * option_choice int RW Which option choice is currently selected.
+ * item_id int RW Which option item is currently selected.
+ * subitem_id int RW Which option subitem is currently selected.
* text string RW Text in the entry box.
*/